@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: attach.c,v 1.10 1998/10/15 20:33:07 roessler Exp $";
+static const char rcsid[]="$Id: attach.c,v 1.11 1998/10/28 16:39:54 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -506,7 +506,8 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag)
     info.fp = fp;
     info.bdy = a;
     info.ctx = Context;
-    rc = mutt_do_pager (descrip, pagerfile, is_message, &info);
+    rc = mutt_do_pager (descrip, pagerfile,
+			is_message ? M_PAGER_MESSAGE : 0, &info);
   }
   else
     rc = 0;
