@@ -1,4 +1,4 @@
-static char rcsid[]="$Id: buffy.c,v 1.5 1998/10/13 20:44:41 roessler Exp $";
+static const char rcsid[]="$Id: buffy.c,v 1.7 1998/10/15 20:33:09 roessler Exp $";
 /* 
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -97,7 +97,7 @@ int test_last_status_new (FILE * f)
     return (0);
 
   hdr = mutt_new_header ();
-  mutt_read_rfc822_header (f, hdr);
+  mutt_read_rfc822_header (f, hdr, 0);
   if (!(hdr->read || hdr->old))
     result = 1;
   mutt_free_header (&hdr);
