@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: compose.c,v 1.25 1998/10/15 20:33:15 roessler Exp $";
+static const char rcsid[]="$Id: compose.c,v 1.29 1998/10/27 09:42:02 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -59,6 +59,19 @@ enum
 };
 
 #define HDR_XOFFSET 10
+#define TITLE_FMT "%10s"
+#define W (COLS - HDR_XOFFSET)
+
+static char *Prompts[] =
+{
+  "From: ",
+  "To: ",
+  "Cc: ",
+  "Bcc: ",
+  "Subject: ",
+  "Reply-To: ",
+  "Fcc: "
+};
 
 static struct mapping_t ComposeHelp[] = {
   { N_("Send"),    OP_COMPOSE_SEND_MESSAGE },
@@ -72,7 +85,7 @@ static struct mapping_t ComposeHelp[] = {
   { NULL }
 };
 
-void snd_entry (char *b, size_t blen, MUTTMENU *menu, int num)
+static void snd_entry (char *b, size_t blen, MUTTMENU *menu, int num)
 {
     mutt_FormatString (b, blen, NONULL (AttachFormat), mutt_attach_fmt,
 	    (unsigned long)(((ATTACHPTR **) menu->data)[num]),
@@ -84,9 +97,31 @@ void snd_entry (char *b, size_t blen, MUTTMENU *menu, int num)
 #ifdef _PGPPATH
 #include "pgp.h"
 
-static int pgp_send_menu (int bits)
+static void redraw_pgp_lines (int pgp)
+{
+  mvaddstr (HDR_PGP, 0,     "     PGP: ");
+  if ((pgp & (PGPENCRYPT | PGPSIGN)) == (PGPENCRYPT | PGPSIGN))
+    addstr (_("Sign, Encrypt"));
+  else if (pgp & PGPENCRYPT)
+    addstr (_("Encrypt"));
+  else if (pgp & PGPSIGN)
+    addstr (_("Sign"));
+  else
+    addstr (_("Clear"));
+  clrtoeol ();
+
+  move (HDR_PGPSIGINFO, 0);
+  clrtoeol ();
+  if (pgp & PGPSIGN)
+  {
+    printw ("%s%s", _(" sign as: "), PgpSignAs ? PgpSignAs : _("<default>"));
+    mvprintw (HDR_PGPSIGINFO, 40, "%s%s", _("MIC algorithm: "),
+	      NONULL(PgpSignMicalg));
+  }
+}
+
+static int pgp_send_menu (int bits, int *redraw)
 {
-  event_t ch;
   char *p;
   char *micalg = NULL;
   char input_signas[SHORT_STRING];
@@ -94,97 +129,94 @@ static int pgp_send_menu (int bits)
   KEYINFO *secring;
 
   struct pgp_vinfo *pgp = pgp_get_vinfo(PGP_SIGN);
-  
-  mvaddstr (LINES-1, 0, _("(e)ncrypt, (s)ign, sign (a)s, (b)oth, select (m)ic algorithm, or (f)orget it? "));
-  clrtoeol ();
-  do
-  {
-    mutt_refresh ();
-    
-    ch  = mutt_getch();
-    if (ch.ch == EOF)
-      break;
 
-    if (ch.ch == 'a')
+  switch (mutt_multi_choice (_("(e)ncrypt, (s)ign, sign (a)s, (b)oth, select (m)ic algorithm, or (f)orget it? "),
+			     _("esabmf")))
+  {
+  case 1: /* (e)ncrypt */
+    bits |= PGPENCRYPT;
+    break;
+
+  case 2: /* (s)ign */
+    bits |= PGPSIGN;
+    break;
+
+  case 3: /* sign (a)s */
+    unset_option(OPTPGPCHECKTRUST);
+
+    if(pgp)
     {
-      unset_option(OPTPGPCHECKTRUST);
-      
-      if(pgp)
+      if(!(secring = pgp->read_secring(pgp)))
       {
-	if(!(secring = pgp->read_secring(pgp)))
+	mutt_error _("Can't open your secret key ring!");
+	bits &= ~PGPSIGN;
+      }
+      else 
+      {
+	if ((p = pgp_ask_for_key (pgp, secring, _("Sign as: "), 
+				  NULL, KEYFLAG_CANSIGN, &micalg)))
 	{
-	  mutt_error _("Can't open your secret key ring!");
-	  bits &= ~PGPSIGN;
+	  snprintf (input_signas, sizeof (input_signas), "0x%s", p);
+	  safe_free((void **) &PgpSignAs);
+	  PgpSignAs = safe_strdup(input_signas);
+	  safe_free((void **) &PgpSignMicalg);
+	  PgpSignMicalg = micalg;	/* micalg is malloc()ed by pgp_ask_for_key */
+	  pgp_void_passphrase ();	/* probably need a different passphrase */
+	  safe_free ((void **) &p);
+	  bits |= PGPSIGN;
+	}
+
+	pgp_close_keydb(&secring);
+	*redraw = REDRAW_FULL;
+      }
+    }
+    else
+    {
+      bits &= ~PGPSIGN;
+      mutt_error _("An unkown PGP version was defined for signing.");
+    }
+    break;
+
+  case 4: /* (b)oth */
+    bits = PGPENCRYPT | PGPSIGN;
+    break;
+
+  case 5: /* select (m)ic algorithm */
+    if(!(bits & PGPSIGN))
+      mutt_error _("This doesn't make sense if you don't want to sign the message.");
+    else
+    {
+      /* Copy the existing MIC algorithm into place */
+      strfcpy(input_micalg, NONULL(PgpSignMicalg), sizeof(input_micalg));
+
+      if(mutt_get_field (_("MIC algorithm: "), input_micalg, sizeof(input_micalg), 0) == 0)
+      {
+	if(strcasecmp(input_micalg, "pgp-md5") && strcasecmp(input_micalg, "pgp-sha1")
+	   && strcasecmp(input_micalg, "pgp-rmd160"))
+	{
+	  mutt_error _("Unknown MIC algorithm, valid ones are: pgp-md5, pgp-sha1, pgp-rmd160");
 	}
 	else 
 	{
-	  if ((p = pgp_ask_for_key (pgp, secring, _("Sign as: "), 
-				    NULL, KEYFLAG_CANSIGN, &micalg)))
-	  {
-	    snprintf (input_signas, sizeof (input_signas), "0x%s", p);
-	    safe_free((void **) &PgpSignAs);
-	    PgpSignAs = safe_strdup(input_signas);
-	    safe_free((void **) &PgpSignMicalg);
-	    PgpSignMicalg = micalg;	/* micalg is malloc()ed by pgp_ask_for_key */
-	    pgp_void_passphrase (); 	/* probably need a different passphrase */
-	    safe_free ((void **) &p);
-	    bits |= PGPSIGN;
-	  }
-	  
-	  pgp_close_keydb(&secring);
+	  safe_free((void **) &PgpSignMicalg);
+	  PgpSignMicalg = safe_strdup(input_micalg);
 	}
       }
-      else
-      {
-	bits &= ~PGPSIGN;
-	mutt_error _("An unkown PGP version was defined for signing.");
-      }
     }
-    else if (ch.ch == 'm')
-    {
-      if(!(bits & PGPSIGN))
-	mutt_error _("This doesn't make sense if you don't want to sign the message.");
-      else
-      {
-	/* Copy the existing MIC algorithm into place */
-	strfcpy(input_micalg, NONULL(PgpSignMicalg), sizeof(input_micalg));
+    break;
 
-	if(mutt_get_field (_("MIC algorithm: "), input_micalg, sizeof(input_micalg), 0) == 0)
-	{
-	  if(strcasecmp(input_micalg, "pgp-md5") && strcasecmp(input_micalg, "pgp-sha1")
-	     && strcasecmp(input_micalg, "pgp-rmd160"))
-	  {
-	    mutt_error _("Unknown MIC algorithm, valid ones are: pgp-md5, pgp-sha1, pgp-rmd160");
-	  }
-	  else 
-	  {
-	    safe_free((void **) &PgpSignMicalg);
-	    PgpSignMicalg = safe_strdup(input_micalg);
-	  }
-	}
-      }
-    }
-    else if (ch.ch == 'e')
-      bits |= PGPENCRYPT;
-    else if (ch.ch == 's')
-      bits |= PGPSIGN;
-    else if (ch.ch == 'b')
-      bits = PGPENCRYPT | PGPSIGN;
-    else if (ch.ch == 'f')
-      bits = 0;
-    else
-    {
-      BEEP ();
-      ch.ch = 0;
-    }
+  case 6: /* (f)orget it */
+    bits = 0;
+    break;
   }
-  while (ch.ch == 0);
-  CLEARLINE (LINES-1);
-  mutt_refresh ();
+  if (!*redraw)
+    redraw_pgp_lines (bits);
   return (bits);
 }
 #endif /* _PGPPATH */
 
+
+
 static int
 check_attachments(ATTACHPTR **idx, short idxlen)
 {
@@ -219,137 +251,49 @@ check_attachments(ATTACHPTR **idx, short idxlen)
   return 0;
 }
 
-static void draw_envelope (HEADER *msg, char *fcc)
+static void draw_envelope_addr (int line, ADDRESS *addr)
 {
   char buf[STRING];
-  int w = COLS - HDR_XOFFSET;
 
-  mvaddstr (HDR_FROM, 0,    "    From: ");
   buf[0] = 0;
-  rfc822_write_address (buf, sizeof (buf), msg->env->from);
-  printw ("%-*.*s", w, w, buf);
+  rfc822_write_address (buf, sizeof (buf), addr);
+  mvprintw (line, 0, TITLE_FMT "%-*.*s", Prompts[line - 1], W, W, buf);
+}
 
-  mvaddstr (HDR_TO, 0,      "      To: ");
-  buf[0] = 0;
-  rfc822_write_address (buf, sizeof (buf), msg->env->to);
-  printw ("%-*.*s", w, w, buf);
-
-  mvaddstr (HDR_CC, 0,      "      Cc: ");
-  buf[0] = 0;
-  rfc822_write_address (buf, sizeof (buf), msg->env->cc);
-  printw ("%-*.*s", w, w, buf);
-
-  mvaddstr (HDR_BCC, 0,     "     Bcc: ");
-  buf[0] = 0;
-  rfc822_write_address (buf, sizeof (buf), msg->env->bcc);
-  printw ("%-*.*s", w, w, buf);
-
-  mvaddstr (HDR_SUBJECT, 0, " Subject: ");
-  if (msg->env->subject)
-    printw ("%-*.*s", w, w, msg->env->subject);
-  else
-    clrtoeol ();
-
-  mvaddstr (HDR_REPLYTO, 0, "Reply-To: ");
-  if (msg->env->reply_to)
-  {
-    buf[0] = 0;
-    rfc822_write_address (buf, sizeof (buf), msg->env->reply_to);
-    printw ("%-*.*s", w, w, buf);
-  }
-  else
-    clrtoeol ();
-
-  mvaddstr (HDR_FCC, 0,     "     Fcc: ");
-  addstr (fcc);
+static void draw_envelope (HEADER *msg, char *fcc)
+{
+  draw_envelope_addr (HDR_FROM, msg->env->from);
+  draw_envelope_addr (HDR_TO, msg->env->to);
+  draw_envelope_addr (HDR_CC, msg->env->cc);
+  draw_envelope_addr (HDR_BCC, msg->env->bcc);
+  mvprintw (HDR_SUBJECT, 0, TITLE_FMT "%-*.*s", Prompts[HDR_SUBJECT - 1], W, W,
+	    NONULL(msg->env->subject));
+  draw_envelope_addr (HDR_REPLYTO, msg->env->reply_to);
+  mvprintw (HDR_FCC, 0, TITLE_FMT "%-*.*s", Prompts[HDR_FCC - 1], W, W, fcc);
 
 
 
 #ifdef _PGPPATH
-  mvaddstr (HDR_PGP, 0,     "     PGP: ");
-  if ((msg->pgp & (PGPENCRYPT | PGPSIGN)) == (PGPENCRYPT | PGPSIGN))
-    addstr (_("Sign, Encrypt"));
-  else if (msg->pgp & PGPENCRYPT)
-    addstr (_("Encrypt"));
-  else if (msg->pgp & PGPSIGN)
-    addstr (_("Sign"));
-  else
-    addstr (_("Clear"));
-  clrtoeol ();
-
-  if (msg->pgp & PGPSIGN)
-  {
-    mvaddstr (HDR_PGPSIGINFO, 0, _(" sign as: "));
-    if (PgpSignAs)
-      printw ("%s", PgpSignAs);
-    else
-      printw ("%s", _("<default>"));
-    clrtoeol ();
-    mvaddstr (HDR_PGPSIGINFO, 40, _("MIC algorithm: "));
-    printw ("%s", NONULL(PgpSignMicalg));
-    clrtoeol ();
-  }
-  else
-  {
-    mvaddstr(HDR_PGPSIGINFO, 0, "");
-    clrtoeol();
-  }
-  
+  redraw_pgp_lines (msg->pgp);
 #endif /* _PGPPATH */
 
 
 
-
-
-
-
-
-
-
-
-  mvaddstr (HDR_ATTACH - 1, 0, "===== Attachments =====");
+  mvaddstr (HDR_ATTACH - 1, 0, _("===== Attachments ====="));
 }
 
-static int edit_address_list (int line, ENVELOPE *env)
+static int edit_address_list (int line, ADDRESS **addr)
 {
   char buf[HUGE_STRING] = ""; /* needs to be large for alias expansion */
-  ADDRESS **addr;
-  char *prompt;
-
-  switch (line)
-  {
-    case HDR_FROM:
-      prompt = "From: ";
-      addr = &env->from;
-      break;
-    case HDR_TO:
-      prompt = "To: ";
-      addr = &env->to;
-      break;
-    case HDR_CC:
-      prompt = "Cc: ";
-      addr = &env->cc;
-      break;
-    case HDR_BCC:
-      prompt = "Bcc: ";
-      addr = &env->bcc;
-      break;
-    case HDR_REPLYTO:
-      prompt = "Reply-To: ";
-      addr = &env->reply_to;
-      break;
-    default:
-      return 0;
-  }
 
   rfc822_write_address (buf, sizeof (buf), *addr);
-  if (mutt_get_field (prompt, buf, sizeof (buf), M_ALIAS) == 0)
+  if (mutt_get_field (Prompts[line - 1], buf, sizeof (buf), M_ALIAS) == 0)
   {
     rfc822_free_address (addr);
     *addr = mutt_parse_adrlist (*addr, buf);
     *addr = mutt_expand_aliases (*addr);
   }
-  
+
   if (option (OPTNEEDREDRAW))
   {
     unset_option (OPTNEEDREDRAW);
@@ -359,8 +303,7 @@ static int edit_address_list (int line, ENVELOPE *env)
   /* redraw the expanded list so the user can see the result */
   buf[0] = 0;
   rfc822_write_address (buf, sizeof (buf), *addr);
-  move (line, HDR_XOFFSET);
-  printw ("%-*.*s", COLS - HDR_XOFFSET, COLS - HDR_XOFFSET, buf);
+  mvprintw (line, HDR_XOFFSET, "%-*.*s", W, W, buf);
 
   return 0;
 }
@@ -462,16 +405,16 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	menu->pagelen = LINES - HDR_ATTACH - 2;
 	break;
       case OP_COMPOSE_EDIT_FROM:
-	menu->redraw = edit_address_list (HDR_FROM, msg->env);
+	menu->redraw = edit_address_list (HDR_FROM, &msg->env->from);
 	break;
       case OP_COMPOSE_EDIT_TO:
-	menu->redraw = edit_address_list (HDR_TO, msg->env);
+	menu->redraw = edit_address_list (HDR_TO, &msg->env->to);
 	break;
       case OP_COMPOSE_EDIT_BCC:
-	menu->redraw = edit_address_list (HDR_BCC, msg->env);
+	menu->redraw = edit_address_list (HDR_BCC, &msg->env->bcc);
 	break;
       case OP_COMPOSE_EDIT_CC:
-	menu->redraw = edit_address_list (HDR_CC, msg->env);
+	menu->redraw = edit_address_list (HDR_CC, &msg->env->cc);
 	break;
       case OP_COMPOSE_EDIT_SUBJECT:
 	if (msg->env->subject)
@@ -485,12 +428,11 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  move (HDR_SUBJECT, HDR_XOFFSET);
 	  clrtoeol ();
 	  if (msg->env->subject)
-	    printw ("%-*.*s", COLS-HDR_XOFFSET, COLS-HDR_XOFFSET,
-		    msg->env->subject);
+	    printw ("%-*.*s", W, W, msg->env->subject);
 	}
 	break;
       case OP_COMPOSE_EDIT_REPLY_TO:
-	menu->redraw = edit_address_list (HDR_REPLYTO, msg->env);
+	menu->redraw = edit_address_list (HDR_REPLYTO, &msg->env->reply_to);
 	break;
       case OP_COMPOSE_EDIT_FCC:
 	strfcpy (buf, fcc, sizeof (buf));
@@ -498,8 +440,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	{
 	  strfcpy (fcc, buf, _POSIX_PATH_MAX);
 	  mutt_pretty_mailbox (fcc);
-	  mvprintw (HDR_FCC, HDR_XOFFSET, "%-*.*s",
-		    COLS - HDR_XOFFSET, COLS - HDR_XOFFSET, fcc);
+	  mvprintw (HDR_FCC, HDR_XOFFSET, "%-*.*s", W, W, fcc);
 	  fccSet = 1;
 	}
 	MAYBE_REDRAW (menu->redraw);
@@ -584,16 +525,6 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 
 
 
-
-
-
-
-
-
-
-
-
-
       case OP_COMPOSE_ATTACH_FILE:
       case OP_COMPOSE_ATTACH_MESSAGE:
 
@@ -989,11 +920,6 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	}
 	break;
 
-
-
-
-
-
       case OP_COMPOSE_EDIT_MIME:
 	CHECK_COUNT;
 	if (mutt_edit_attachment (idx[menu->current]->content))
@@ -1029,11 +955,6 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 	  menu->redraw = menu->tagprefix ? REDRAW_FULL : REDRAW_CURRENT; 
 	break;
 
-
-
-
-
-
       case OP_EXIT:
 	if ((i = query_quadoption (OPT_POSTPONE, _("Postpone this message?"))) == M_NO)
 	{
@@ -1080,6 +1001,11 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
       case OP_COMPOSE_WRITE_MESSAGE:
 
        fname[0] = '\0';
+       if (Context)
+       {
+	 strfcpy (fname, NONULL (Context->path), sizeof (fname));
+	 mutt_pretty_mailbox (fname);
+       }
        if (idxlen)
          msg->content = idx[0]->content;
        if (mutt_enter_fname (_("Write message to mailbox"), fname, sizeof (fname),
@@ -1094,7 +1020,7 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
 
 	 oldhdrdate = option(OPTUSEHEADERDATE);
 	 set_option(OPTUSEHEADERDATE);
-         if (mutt_write_fcc (NONULL (fname), msg, NULL, 1) < 0)
+         if (mutt_write_fcc (NONULL (fname), msg, NULL, 1, NULL) < 0)
            msg->content = mutt_remove_multipart (msg->content);
          else
            mutt_message _("Message written.");
@@ -1102,11 +1028,12 @@ int mutt_compose_menu (HEADER *msg,   /* structure for new message */
        }
        break;
 
+
+
 #ifdef _PGPPATH
       case OP_COMPOSE_PGP_MENU:
 
-	msg->pgp = pgp_send_menu (msg->pgp);
-	menu->redraw = REDRAW_FULL;
+	msg->pgp = pgp_send_menu (msg->pgp, &menu->redraw);
 	break;
 
       case OP_FORGET_PASSPHRASE:
