@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: curs_lib.c,v 1.17 1998/10/15 20:33:18 roessler Exp $";
+static const char rcsid[]="$Id: curs_lib.c,v 1.20 1998/10/28 21:43:27 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -182,6 +182,16 @@ void mutt_query_exit (void)
   Signals &= ~S_INTERRUPT;
 }
 
+static void clean_error_buf(void)
+{
+  char *s;
+  for(s = Errorbuf; *s; s++)
+  {
+    if(!IsPrint(*s))
+      *s = '.';
+  }
+}
+
 void mutt_curses_error (const char *fmt, ...)
 {
   va_list ap;
@@ -192,6 +202,7 @@ void mutt_curses_error (const char *fmt, ...)
   
   dprint (1, (debugfile, "%s\n", Errorbuf));
   Errorbuf[ (COLS < sizeof (Errorbuf) ? COLS : sizeof (Errorbuf)) - 2 ] = 0;
+  clean_error_buf();
 
   BEEP ();
   SETCOLOR (MT_COLOR_ERROR);
@@ -212,6 +223,7 @@ void mutt_message (const char *fmt, ...)
   va_end (ap);
 
   Errorbuf[ (COLS < sizeof (Errorbuf) ? COLS : sizeof (Errorbuf)) - 2 ] = 0;
+  clean_error_buf();
 
   SETCOLOR (MT_COLOR_MESSAGE);
   mvaddstr (LINES - 1, 0, Errorbuf);
@@ -378,3 +390,42 @@ void mutt_curs_set (int cursor)
   curs_set (cursor);
 }
 #endif
+
+int mutt_multi_choice (char *prompt, char *letters)
+{
+  event_t ch;
+  int choice;
+  char *p;
+
+  mvaddstr (LINES - 1, 0, prompt);
+  clrtoeol ();
+  FOREVER
+  {
+    mutt_refresh ();
+    ch  = mutt_getch ();
+    if (ch.ch == -1)
+    {
+      choice = -1;
+      break;
+    }
+    else
+    {
+      p = strchr (letters, ch.ch);
+      if (p)
+      {
+	choice = p - letters + 1;
+	break;
+      }
+      else if (ch.ch <= '9' && ch.ch > '0')
+      {
+	choice = ch.ch - '0';
+	if (choice <= strlen (letters))
+	  break;
+      }
+    }
+    BEEP ();
+  }
+  CLEARLINE (LINES - 1);
+  mutt_refresh ();
+  return choice;
+}
