@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: curs_main.c,v 1.22 1998/10/15 20:33:19 roessler Exp $";
+static const char rcsid[]="$Id: curs_main.c,v 1.23 1998/10/28 16:39:56 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -243,7 +243,6 @@ int mutt_index_menu (void)
 {
   char buf[LONG_STRING], helpstr[SHORT_STRING];
   int op = OP_NULL;
-  event_t event = {-1, 0};
   int done = 0;                /* controls when to exit the "event" loop */
   int i = 0, j;
   int tag = 0;                 /* has the tag-prefix command been pressed? */
@@ -473,24 +472,7 @@ int mutt_index_menu (void)
 	move (menu->current - menu->top + menu->offset, COLS - 1);
       mutt_refresh ();
 
-      if (Timeout > 0)
-      {
-	timeout (Timeout * 1000); /* milliseconds */      
-	event = mutt_getch ();
-	dprint(4, (debugfile, "mutt_index_menu[%d]: Got event (%d, %d)\n", __LINE__,
-		   event.ch, event.op));
-	timeout (-1); /* restore blocking operation */
-	op = event.ch;
-	if (op != -1)
-	{
-	  dprint(4, (debugfile, "mutt_index_menu[%d]: Pushing event (%d, %d)\n", __LINE__,
-		     event.ch, event.op));
-	  mutt_ungetch (event.ch, event.op);
-	  op = km_dokey (MENU_MAIN);
-	}
-      }
-      else
-	op = km_dokey (MENU_MAIN);
+      op = km_dokey (MENU_MAIN);
 
       dprint(4, (debugfile, "mutt_index_menu[%d]: Got op %d\n", __LINE__, op));
 
