@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: flags.c,v 1.7 1998/10/15 20:33:25 roessler Exp $";
+static const char rcsid[]="$Id: flags.c,v 1.8 1998/10/22 09:23:48 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -46,12 +46,14 @@ void mutt_set_flag (CONTEXT *ctx, HEADER *h, int flag, int bf)
       {
 	h->deleted = 0;
 	ctx->deleted--;
+#ifdef USE_IMAP
 /* if you undelete a message, the imap server will probably need to know. */
 	if(ctx->magic==M_IMAP) 
 	{
 	  h->changed = 1;
 	  ctx->changed = 1;
 	}
+#endif
       }
       break;
 
