@@ -1,4 +1,4 @@
-/* $Id: functions.h,v 1.11 1998/10/13 20:45:04 roessler Exp $ */
+/* $Id: functions.h,v 1.12 1998/10/20 20:22:59 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -78,7 +78,7 @@ struct binding_t OpMain[] = {
   { "delete-pattern",		OP_MAIN_DELETE_PATTERN,		"D" },
   { "delete-thread",		OP_DELETE_THREAD,		"\004" },
   { "delete-subthread",		OP_DELETE_SUBTHREAD,		"\033d" },
-  { "edit-message",		OP_EDIT_MESSAGE,		"e" },
+  { "edit",			OP_EDIT_MESSAGE,		"e" },
   { "forward-message",		OP_FORWARD_MESSAGE,		"f" },
   { "flag-message",		OP_FLAG_MESSAGE,		"F" },
   { "group-reply",		OP_GROUP_REPLY,			"g" },
@@ -154,7 +154,7 @@ struct binding_t OpPager[] = {
   { "delete-message",	OP_DELETE,			"d" },
   { "delete-thread",	OP_DELETE_THREAD,		"\004" },
   { "delete-subthread",	OP_DELETE_SUBTHREAD,		"\033d" },
-  { "edit-message",	OP_EDIT_MESSAGE,		"e" },
+  { "edit",		OP_EDIT_MESSAGE,		"e" },
   { "forward-message",	OP_FORWARD_MESSAGE,		"f" },
   { "flag-message",	OP_FLAG_MESSAGE,		"F" },
   { "group-reply",	OP_GROUP_REPLY,			"g" },
