@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: gnupgparse.c,v 1.6 1998/10/15 20:33:28 roessler Exp $";
+static const char rcsid[]="$Id: gnupgparse.c,v 1.7 1998/10/21 15:08:23 roessler Exp $";
 /*
  * Copyright (C) 1998 Werner Koch <werner.koch@guug.de>
  *
@@ -168,7 +168,7 @@ static KEYINFO *read_ring(struct pgp_vinfo *pgp, int secret )
     if((devnull = open("/dev/null", O_RDWR)) == -1)
         return NULL;
   
-    thepid = gpg_invoke_list_keys(pgp, NULL, &fp, NULL, devnull, -1, devnull,
+    thepid = gpg_invoke_list_keys(pgp, NULL, &fp, NULL, -1, -1, devnull,
 							NULL, secret);
     if( thepid == -1 )
     {
