@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: handler.c,v 1.19 1998/10/15 20:33:29 roessler Exp $";
+static const char rcsid[]="$Id: handler.c,v 1.20 1998/10/16 09:55:50 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -320,7 +320,7 @@ void mutt_decode_uuencoded (STATE *s, BODY *b, int istext)
     if ((fgets(tmps, sizeof(tmps), s->fpin)) == NULL)
       return;
     len -= strlen(tmps);
-    if ((!strncmp (tmps, "begin", 5)) && isspace (tmps[5]))
+    if ((!strncmp (tmps, "begin", 5)) && ISSPACE (tmps[5]))
       break;
   }
   while(len > 0)
