@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: imap.c,v 1.14 1998/10/15 20:33:36 roessler Exp $";
+static const char rcsid[]="$Id: imap.c,v 1.15 1998/10/27 09:40:36 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -756,7 +756,8 @@ static int imap_exec (char *buf, size_t buflen,
   }
   while (strncmp (buf, seq, SEQLEN) != 0);
 
-  if (CTX_DATA->status == IMAP_NEW_MAIL || CTX_DATA->status == IMAP_EXPUNGE)
+  if (!ctx->closing && 
+      (CTX_DATA->status == IMAP_NEW_MAIL || CTX_DATA->status == IMAP_EXPUNGE))
   {
 
     count = CTX_DATA->newMailCount;
