@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: lib.c,v 1.16 1998/10/16 12:09:37 roessler Exp $";
+static const char rcsid[]="$Id: lib.c,v 1.17 1998/10/22 09:23:49 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -1154,7 +1154,9 @@ int mutt_save_confirm (const char *s, struct stat *st)
   }
   else
   {
+#ifdef USE_IMAP
     if (magic != M_IMAP)
+#endif /* execute the block unconditionally if we don't use imap */
     {
       st->st_mtime = 0;
       st->st_atime = 0;
