@@ -1,4 +1,4 @@
-/* $Id: mutt.h,v 1.26 1998/10/15 19:45:37 roessler Exp $ */
+/* $Id: mutt.h,v 1.28 1998/10/28 18:36:12 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -290,6 +290,7 @@ enum
   OPTFOLLOWUPTO,
   OPTFORCENAME,
   OPTFORWDECODE,
+  OPTFORWWEEDHEADER,
   OPTFORWQUOTE,
   OPTHDRS,
   OPTHEADER,
@@ -632,6 +633,7 @@ typedef struct
   unsigned int quiet : 1;	/* inhibit status messages? */
   unsigned int revsort : 1;	/* mailbox sorted in reverse? */
   unsigned int collapsed : 1;   /* are all threads collapsed? */
+  unsigned int closing : 1;	/* mailbox is being closed */
 } CONTEXT;
 
 typedef struct attachptr
