@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: mx.c,v 1.15 1998/10/15 20:33:45 roessler Exp $";
+static const char rcsid[]="$Id: mx.c,v 1.17 1998/10/27 09:40:38 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -710,6 +710,8 @@ int mx_close_mailbox (CONTEXT *ctx)
   char mbox[_POSIX_PATH_MAX];
   char buf[SHORT_STRING];
 
+  ctx->closing = 1;
+
   if (ctx->readonly || ctx->dontwrite)
   {
     /* mailbox is readonly or we don't want to write */
@@ -1104,8 +1106,8 @@ MESSAGE *mx_open_new_message (CONTEXT *dest, HEADER *hdr, int flags)
     if (dest->magic == M_MMDF)
       fputs (MMDF_SEP, msg->fp);
 
-    if ((msg->magic != M_MAILDIR) && ((msg->magic != M_MH) && msg->magic != M_IMAP) && 
-	(flags & M_ADD_FROM))
+    if ((msg->magic == M_MBOX || msg->magic ==  M_MMDF) &&
+	flags & M_ADD_FROM)
     {
       if (hdr)
       {
