@@ -1,4 +1,4 @@
-/* $Id: mx.h,v 1.4 1998/10/13 20:45:42 roessler Exp $ */
+/* $Id: mx.h,v 1.5 1998/10/22 09:23:51 roessler Exp $ */
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -28,8 +28,10 @@ enum
   M_MBOX = 1,
   M_MMDF,
   M_MH,
-  M_MAILDIR,
-  M_IMAP
+  M_MAILDIR
+#ifdef USE_IMAP
+  , M_IMAP
+#endif
 };
 
 WHERE short DefaultMagic INITVAL (M_MBOX);
