@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: pgp.c,v 1.12 1998/10/15 20:33:50 roessler Exp $";
+static const char rcsid[]="$Id: pgp.c,v 1.13 1998/10/27 15:37:13 roessler Exp $";
 /*
  * Copyright (C) 1996,1997 Michael R. Elkins <me@cs.hmc.edu>
  * Copyright (c) 1998 Thomas Roessler <roessler@guug.de>
@@ -351,11 +351,11 @@ void application_pgp_handler (BODY *m, STATE *s)
       if(s->flags & M_DISPLAY)
       {
 	if (needpass)
-	  state_puts ("[-- BEGIN PGP MESSAGE --]\n\n", s);
+	  state_puts (_("[-- BEGIN PGP MESSAGE --]\n\n"), s);
 	else if (pgp_keyblock)
-	  state_puts ("[-- BEGIN PGP PUBLIC KEY BLOCK --]\n", s);
+	  state_puts (_("[-- BEGIN PGP PUBLIC KEY BLOCK --]\n"), s);
 	else
-	  state_puts ("[-- BEGIN PGP SIGNED MESSAGE --]\n\n", s);
+	  state_puts (_("[-- BEGIN PGP SIGNED MESSAGE --]\n\n"), s);
       }
 
       /* Use PGP's output if there was no clearsig signature. */
@@ -457,9 +457,9 @@ void application_pgp_handler (BODY *m, STATE *s)
       if (s->flags & M_DISPLAY)
       {
 	if (needpass)
-	  state_puts ("\n[-- END PGP MESSAGE --]\n", s);
+	  state_puts (_("\n[-- END PGP MESSAGE --]\n"), s);
 	else if (pgp_keyblock)
-	  state_puts ("[-- END PGP PUBLIC KEY BLOCK --]\n", s);
+	  state_puts (_("[-- END PGP PUBLIC KEY BLOCK --]\n"), s);
 	else
 	  state_puts ("\n[-- END PGP SIGNED MESSAGE --]\n", s);
       }
