@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: postpone.c,v 1.16 1998/10/19 20:08:10 roessler Exp $";
+static const char rcsid[]="$Id: postpone.c,v 1.18 1998/10/27 09:41:15 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -158,13 +158,15 @@ static HEADER *select_msg (void)
  *	hdr	envelope/attachment info for recalled message
  *	cur	if message was a reply, `cur' is set to the message which
  *		`hdr' is in reply to
+ *	fcc	fcc for the recalled message
+ *	fcclen	max length of fcc
  *
  * return vals:
  *	-1		error/no messages
  *	0		normal exit
  *	SENDREPLY	recalled message is a reply
  */
-int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur)
+int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur, char *fcc, size_t fcclen)
 {
   HEADER *h;
   int code = SENDPOSTPONED;
@@ -205,7 +207,7 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur)
     return (-1);
   }
 
-  if (mutt_edit_message (PostContext, hdr, h) < 0)
+  if (mutt_prepare_edit_message (PostContext, hdr, h) < 0)
   {
       mx_fastclose_mailbox (PostContext);
       safe_free ((void **) &PostContext);
@@ -251,6 +253,23 @@ int mutt_get_postponed (CONTEXT *ctx, HEADER *hdr, HEADER **cur)
       if (*cur)
 	code |= SENDREPLY;
     }
+    else if (strncasecmp ("X-Mutt-Fcc:", tmp->data, 11) == 0)
+    {
+      p = tmp->data + 11;
+      SKIPWS (p);
+      strfcpy (fcc, p, fcclen);
+      mutt_pretty_mailbox (fcc);
+
+      /* remove the X-Mutt-Fcc: header field */
+      next = tmp->next;
+      if (last)
+	last->next = tmp->next;
+      else
+	hdr->env->userhdrs = tmp->next;
+      tmp->next = NULL;
+      mutt_free_list (&tmp);
+      tmp = next;
+    }
 
 
 
@@ -371,7 +390,7 @@ int mutt_parse_pgp_hdr (char *p, int set_signas)
 
 
 
-int mutt_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
+int mutt_prepare_edit_message (CONTEXT *ctx, HEADER *newhdr, HEADER *hdr)
 {
   MESSAGE *msg = mx_open_message (ctx, hdr->msgno);
   char file[_POSIX_PATH_MAX];
