@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: send.c,v 1.14 1998/10/16 09:55:39 roessler Exp $";
+static const char rcsid[]="$Id: send.c,v 1.21 1998/10/28 21:32:13 roessler Exp $";
 /*
  * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
  * 
@@ -337,7 +337,8 @@ static int include_forward (CONTEXT *ctx, HEADER *cur, FILE *out)
   if (option (OPTFORWDECODE))
   {
     cmflags |= M_CM_DECODE;
-    chflags |= CH_WEED;
+    if (option (OPTFORWWEEDHEADER))
+      chflags |= CH_WEED;
   }
   if (option (OPTFORWQUOTE))
     cmflags |= M_CM_PREFIX;
@@ -404,13 +405,19 @@ static int default_to (ADDRESS **to, ENVELOPE *env, int group)
   }
   else if (env->reply_to)
   {
-    if (option (OPTIGNORELISTREPLYTO) &&
+    if (mutt_addrcmp (env->from, env->reply_to) || 
+	(option (OPTIGNORELISTREPLYTO) &&
 	mutt_is_mail_list (env->reply_to) &&
 	(mutt_addrsrc (env->reply_to, env->to) ||
-	mutt_addrsrc (env->reply_to, env->cc)))
+	mutt_addrsrc (env->reply_to, env->cc))))
     {
       /* If the Reply-To: address is a mailing list, assume that it was
        * put there by the mailing list, and use the From: address
+       * 
+       * We also take the from header if our correspondant has a reply-to
+       * header which is identical to the electronic mail address given
+       * in his From header.
+       * 
        */
       rfc822_append (to, env->from);
     }
@@ -439,23 +446,6 @@ static int default_to (ADDRESS **to, ENVELOPE *env, int group)
   return (0);
 }
 
-static LIST *make_references(ENVELOPE *e)
-{
-  LIST *t, *l;
-  
-  l = mutt_copy_list(e->references);
-  
-  if(e->message_id)
-  {
-    t = mutt_new_list();
-    t->data = safe_strdup(e->message_id);
-    t->next = l;
-    l = t;
-  }
-  
-  return l;
-}
-
 static int fetch_recips (ENVELOPE *out, ENVELOPE *in, int flags)
 {
   ADDRESS *tmp;
@@ -481,6 +471,23 @@ static int fetch_recips (ENVELOPE *out, ENVELOPE *in, int flags)
   return 0;
 }
 
+static LIST *make_references(ENVELOPE *e)
+{
+  LIST *t, *l;
+  
+  l = mutt_copy_list(e->references);
+  
+  if(e->message_id)
+  {
+    t = mutt_new_list();
+    t->data = safe_strdup(e->message_id);
+    t->next = l;
+    l = t;
+  }
+  
+  return l;
+}
+
 static int
 envelope_defaults (ENVELOPE *env, CONTEXT *ctx, HEADER *cur, int flags)
 {
@@ -850,7 +857,7 @@ ci_send_message (int flags,		/* send mode */
   char *signmic = NULL;
 #endif
 
-  if (!flags && quadoption (OPT_RECALL) != M_NO && mutt_num_postponed ())
+  if (!flags && !msg && quadoption (OPT_RECALL) != M_NO && mutt_num_postponed ())
   {
     /* If the user is composing a new message, check to see if there
      * are any postponed messages first.
@@ -883,12 +890,12 @@ ci_send_message (int flags,		/* send mode */
 
     if (flags == SENDEDITMSG)
     {
-      if (mutt_edit_message(ctx, msg, cur) < 0)
+      if (mutt_prepare_edit_message(ctx, msg, cur) < 0)
 	goto cleanup;
     }
     else if (flags == SENDPOSTPONED)
     {
-      if ((flags = mutt_get_postponed (ctx, msg, &cur)) < 0)
+      if ((flags = mutt_get_postponed (ctx, msg, &cur, fcc, sizeof (fcc))) < 0)
 	goto cleanup;
     }
 
@@ -940,13 +947,13 @@ ci_send_message (int flags,		/* send mode */
   if (cur && option (OPTREVNAME) && !(flags & (SENDPOSTPONED | SENDEDITMSG)))
   {
     /* we shouldn't have to worry about freeing `msg->env->from' before
-       setting it here since this code will only execute when doing some
-       sort of reply.  the pointer will only be set when using the -H command
-       line option */
+     * setting it here since this code will only execute when doing some
+     * sort of reply.  the pointer will only be set when using the -H command
+     * line option */
     msg->env->from = set_reverse_name (cur->env);
   }
 
-  if (!msg->env->from && option (OPTUSEFROM) && !(flags & SENDEDITMSG))
+  if (!msg->env->from && option (OPTUSEFROM) && !(flags & (SENDEDITMSG|SENDPOSTPONED)))
     msg->env->from = mutt_default_from ();
 
   if (flags & SENDBATCH) 
@@ -976,9 +983,10 @@ ci_send_message (int flags,		/* send mode */
     }
 
     /* the from address must be set here regardless of whether or not
-       $use_from is set so that the `~P' (from you) operator in send-hook
-       patterns will work.  if $use_from is unset, the from address is killed
-       after send-hooks are evaulated */
+     * $use_from is set so that the `~P' (from you) operator in send-hook
+     * patterns will work.  if $use_from is unset, the from address is killed
+     * after send-hooks are evaulated */
+
     if (!msg->env->from)
     {
       msg->env->from = mutt_default_from ();
@@ -986,6 +994,7 @@ ci_send_message (int flags,		/* send mode */
     }
 
     /* change settings based upon recipients */
+    
     mutt_send_hook (msg);
 
     if (killfrom)
@@ -1097,7 +1106,8 @@ ci_send_message (int flags,		/* send mode */
   }
 
   /* specify a default fcc.  if we are in batchmode, only save a copy of
-     the message if the value of $copy is yes or ask-yes */
+   * the message if the value of $copy is yes or ask-yes */
+
   if (!fcc[0] && (!(flags & SENDBATCH) || (quadoption (OPT_COPY) & 0x1)))
   {
     /* set the default FCC */
@@ -1133,7 +1143,7 @@ main_loop:
       /* postpone the message until later. */
       if (msg->content->next)
 	msg->content = mutt_make_multipart (msg->content);
-      if (!Postponed || mutt_write_fcc (NONULL (Postponed), msg, (cur && (flags & SENDREPLY)) ? cur->env->message_id : NULL, 1) < 0)
+      if (!Postponed || mutt_write_fcc (NONULL (Postponed), msg, (cur && (flags & SENDREPLY)) ? cur->env->message_id : NULL, 1, fcc) < 0)
       {
 	msg->content = mutt_remove_multipart (msg->content);
 	goto main_loop;
@@ -1273,7 +1283,7 @@ main_loop:
 full_fcc:
 #endif /* _PGPPATH */
     if (msg->content)
-      mutt_write_fcc (fcc, msg, NULL, 0);
+      mutt_write_fcc (fcc, msg, NULL, 0, NULL);
     msg->content = tmpbody;
 
 #ifdef _PGPPATH
